#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-pandoc-crossref-z-pandoc-crossref-internal
version:              0.3.12.0
package-name:         pandoc-crossref
lib-name:             pandoc-crossref-internal
id:
    pandoc-crossref-0.3.12.0-2cmH6m9QZwr4CxnxbrYuGz-pandoc-crossref-internal

key:
    pandoc-crossref-0.3.12.0-2cmH6m9QZwr4CxnxbrYuGz-pandoc-crossref-internal

license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  b5bad72c268b3d63f15dc5e185a7dd8d
exposed-modules:
    Text.Pandoc.CrossRef.References
    Text.Pandoc.CrossRef.References.Blocks
    Text.Pandoc.CrossRef.References.List
    Text.Pandoc.CrossRef.References.Refs
    Text.Pandoc.CrossRef.References.Types
    Text.Pandoc.CrossRef.Util.CodeBlockCaptions
    Text.Pandoc.CrossRef.Util.CustomLabels
    Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
    Text.Pandoc.CrossRef.Util.Options
    Text.Pandoc.CrossRef.Util.Settings
    Text.Pandoc.CrossRef.Util.Settings.Gen
    Text.Pandoc.CrossRef.Util.Settings.Template
    Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util

import-dirs:          /usr/lib/ghc-8.10.5/site-local/pandoc-crossref-0.3.12.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/pandoc-crossref-0.3.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:
    HSpandoc-crossref-0.3.12.0-2cmH6m9QZwr4CxnxbrYuGz-pandoc-crossref-internal

depends:
    base-4.14.2.0 containers-0.6.4.1
    data-default-0.7.1.1-5u8NwVJ9HGT30K0bkKsBOX directory-1.3.6.0
    filepath-1.4.2.1 microlens-0.4.12.0-7mbtYeVEJj9DE2AV66WaoK
    microlens-mtl-0.2.0.1-JgTbTlYIvEKBoII676UfjM
    microlens-th-0.4.3.10-L22hJd4Bpy6EfILCAvCrvo mtl-2.2.2
    pandoc-2.14.0.2-jEtpJabXwvEulHL945ETu
    pandoc-types-1.22-K1U3otiVNjpE9PSImfewvu
    roman-numerals-0.5.1.5-Cpw9WRVOaUGDm5MEFOLsXl
    syb-0.7.2.1-5ZaH2aS3V5s5i5LSCPBZnH template-haskell-2.16.0.0
    text-1.2.4.1 utility-ht-0.0.16-24GowJ9ezK6J2J6n2aO3mj

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-crossref
version:              0.3.12.0
visibility:           public
id:                   pandoc-crossref-0.3.12.0-NcuD7ORygqHdumaYATbzS
key:                  pandoc-crossref-0.3.12.0-NcuD7ORygqHdumaYATbzS
license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  48a3e4312cf6d9760209bfe22612905e
exposed:              True
exposed-modules:      Text.Pandoc.CrossRef
import-dirs:          /usr/lib/ghc-8.10.5/site-local/pandoc-crossref-0.3.12.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/pandoc-crossref-0.3.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:         HSpandoc-crossref-0.3.12.0-NcuD7ORygqHdumaYATbzS
depends:
    base-4.14.2.0 mtl-2.2.2 pandoc-2.14.0.2-jEtpJabXwvEulHL945ETu
    pandoc-crossref-0.3.12.0-2cmH6m9QZwr4CxnxbrYuGz-pandoc-crossref-internal
    pandoc-types-1.22-K1U3otiVNjpE9PSImfewvu text-1.2.4.1

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

